@@ -52,6 +52,7 @@ $GLOBALS['LSconfig'] = array(
 */
       'LSprofiles' => array (
         'admin' => array (
+          'label' => 'Administrator',
           'o=ls' => array (
             'uid=eeggs,ou=people,o=ls' => NULL
           ),
@@ -63,6 +64,7 @@ $GLOBALS['LSconfig'] = array(
           )
         ),
         'godfather' => array (
+          'label' => 'Godfather',
           'LSobjects' => array (
             'LSpeople' => array (
               'attr' => 'lsGodfatherDn',
@@ -213,6 +215,7 @@ $GLOBALS['LSlog']['enable'] = true;
 
 define('NB_LSOBJECT_LIST',30);
 define('NB_LSOBJECT_LIST_SELECT',11);
+$GLOBALS['NB_LSOBJECT_LIST_CHOICES'] = array(30, 60, 100);
 
 define('MAX_SEND_FILE_SIZE',2000000);
 
