@@ -58,6 +58,7 @@ class LSsearch {
     'displaySubDn' => NULL,
     'displayFormat' => NULL,
     'nbObjectsByPage' => NB_LSOBJECT_LIST,
+    'nbObjectsByPageChoices' => NULL,
     'nbPageLinkByPage' => 10,
     'customInfos' => array(),
     'withoutCache' => false,
@@ -333,6 +334,34 @@ class LSsearch {
         $OK=false;
       }
     }
+
+    // nbObjectsByPageChoices
+    if (isset($params['nbObjectsByPageChoices'])) {
+      if (is_array($params['nbObjectsByPageChoices'])) {
+        $choices = array();
+        $choiceError = false;
+        foreach($params['nbObjectsByPageChoices'] as $choice) {
+          if (is_int($choice) && !in_array($choice, $choices)) {
+            $choices[] = $choice;
+          }
+          else {
+            $choiceError = true;
+            break;
+          }
+        }
+        if (!empty($choices) && !$choiceError) {
+          $this -> params['nbObjectsByPageChoices'] = $choices;
+        }
+        else {
+          LSerror :: addErrorCode('LSsearch_03','nbObjectsByPageChoices');
+          $OK = false;
+        }
+      }
+      else {
+        LSerror :: addErrorCode('LSsearch_03','nbObjectsByPageChoices');
+        $OK = false;
+      }
+    }
     
     // Sort Limit
     if (isset($params['sortlimit'])) {
@@ -685,6 +714,9 @@ class LSsearch {
    **/
   public function getParam($key) {
     if(in_array($key,array_keys($this -> params))) {
+      if ($key == 'nbObjectsByPageChoices' && !is_array($this -> params['nbObjectsByPageChoices'])) {
+        return (isset($GLOBALS['NB_LSOBJECT_LIST_CHOICES']) && is_array($GLOBALS['NB_LSOBJECT_LIST_CHOICES'])?$GLOBALS['NB_LSOBJECT_LIST_CHOICES']:range(NB_LSOBJECT_LIST, NB_LSOBJECT_LIST*4, NB_LSOBJECT_LIST));
+}
       return $this -> params[$key];
     }
     return NULL;
